@@ -14,14 +14,13 @@ import (
 	"net"
 	"net/http"
 	"os"
-	"path/filepath"
-	"runtime"
 	"strings"
 	"time"
 
 	"github.com/containernetworking/cni/pkg/skel"
 	"github.com/containernetworking/cni/pkg/types"
 	"github.com/containernetworking/cni/pkg/types/current"
+	lumberjack "gopkg.in/natefinch/lumberjack.v2"
 
 	ovntypes "github.com/ovn-org/ovn-kubernetes/go-controller/pkg/cni/types"
 	"github.com/ovn-org/ovn-kubernetes/go-controller/pkg/config"
@@ -69,13 +68,7 @@ func (p *Plugin) doCNI(url string, req interface{}) ([]byte, error) {
 	client := &http.Client{
 		Transport: &http.Transport{
 			Dial: func(proto, addr string) (net.Conn, error) {
-				var conn net.Conn
-				if runtime.GOOS != "windows" {
-					conn, err = net.Dial("unix", p.socketPath)
-				} else {
-					conn, err = net.Dial("tcp", serverTCPAddress)
-				}
-				return conn, err
+				return net.Dial("unix", p.socketPath)
 			},
 		},
 	}
@@ -104,24 +97,10 @@ func setupLogging(conf *ovntypes.NetConf) {
 
 	if conf.LogLevel != "" {
 		if err = level.Set(conf.LogLevel); err != nil {
-			klog.Warningf("failed to set klog log level to %s: %v", conf.LogLevel, err)
+			klog.Warningf("Failed to set klog log level to %s: %v", conf.LogLevel, err)
 		}
 	}
 	if conf.LogFile != "" {
-		var file *os.File
-
-		if _, err = os.Stat(filepath.Dir(conf.LogFile)); os.IsNotExist(err) {
-			dir := filepath.Dir(conf.LogFile)
-			if err = os.MkdirAll(dir, 0755); err != nil {
-				klog.Warningf("failed to create logfile directory %s (%v).", dir, err)
-				return
-			}
-		}
-		file, err = os.OpenFile(conf.LogFile, os.O_CREATE|os.O_APPEND|os.O_WRONLY, 0660)
-		if err != nil {
-			klog.Warningf("failed to open logfile %s (%v).", conf.LogFile, err)
-			return
-		}
 		klogFlags := flag.NewFlagSet("klog", flag.ExitOnError)
 		klog.InitFlags(klogFlags)
 		if err := klogFlags.Set("logtostderr", "false"); err != nil {
@@ -130,7 +109,13 @@ func setupLogging(conf *ovntypes.NetConf) {
 		if err := klogFlags.Set("alsologtostderr", "true"); err != nil {
 			klog.Warningf("Error setting klog alsologtostderr: %v", err)
 		}
-		klog.SetOutput(file)
+		klog.SetOutput(&lumberjack.Logger{
+			Filename:   conf.LogFile,
+			MaxSize:    conf.LogFileMaxSize, // megabytes
+			MaxBackups: conf.LogFileMaxBackups,
+			MaxAge:     conf.LogFileMaxAge, // days
+			Compress:   true,
+		})
 	}
 }
 
@@ -188,11 +173,6 @@ func (p *Plugin) CmdAdd(args *skel.CmdArgs) error {
 		}
 	}
 
-	err = maybeAddIPv4Hack(args, result)
-	if err != nil {
-		return fmt.Errorf("failed to add hack IPv4 interface: %v", err)
-	}
-
 	return types.PrintResult(result, conf.CNIVersion)
 }
 
